<br/>
<p align="center">
  <h1 align="center">team4958 CUSTOMS</h1>

  <p align="center">
    some life-simplifying python tools for some lazy devs from some lazy devs
    <br/>
    <br/>
    <a href="https://github.com/4958dev/team4958_customs/issues">Report Bug</a>
    .
    <a href="https://github.com/4958dev/team4958_customs/issues">Request Feature</a>
  </p>
</p>

![Contributors](https://img.shields.io/github/contributors/4958dev/team4958_customs?color=dark-green) ![Issues](https://img.shields.io/github/issues/4958dev/team4958_customs) ![License](https://img.shields.io/github/license/4958dev/team4958_customs) 

## About The Project

You probably think that some necessary boring stuff is inevitable and it will always be a part of the process.
We didn't want to agree with it so we created this library which transforms completing the most boring and pissing off tasks to few python strings.

## Getting Started


### Installation

```sh
#Linux/macOS
python3 -m pip install team4958-customs

#Windows
py -3 -m pip install team4958-customs
```

## License

Distributed under the MIT License. See [LICENSE](https://github.com/4958dev/team4958_customs/blob/main/LICENSE.md) for more information.

## Authors

* **arti404** - *laziest dev ever* - [arti404](https://github.com/arti404) - *made everything*
